@@ -1,8 +1,8 @@
 package Cassandra::Client;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::VERSION = '0.13_007'; # TRIAL
+$Cassandra::Client::VERSION = '0.13_008'; # TRIAL
 
-$Cassandra::Client::VERSION = '0.13007';# ABSTRACT: Perl library for accessing Cassandra using its binary network protocol
+$Cassandra::Client::VERSION = '0.13008';# ABSTRACT: Perl library for accessing Cassandra using its binary network protocol
 
 use 5.010;
 use strict;
@@ -85,8 +85,8 @@ sub _connect {
     return _cb($callback, 'Cannot connect: shutdown() has been called') if $self->{shutdown};
 
     # This is ONLY useful if the user doesn't throw away the C::C object on connect errors.
-    if (!$self->{connecting} && $self->{throttler}->should_fail()) {
-        return _cb($callback, "Client-induced connection failure by throttling mechanism");
+    if (!$self->{connecting} && (my $error= $self->{throttler}->should_fail())) {
+        return _cb($callback, $error);
     }
 
     push @{$self->{connect_callbacks}||=[]}, $callback;
@@ -241,7 +241,9 @@ sub _command {
     my $connection= $self->{pool}->get_one;
     goto SLOWPATH if !$connection;
 
-    goto FAILFAST if $self->{throttler}->should_fail();
+    if (my $error= $self->{throttler}->should_fail()) {
+        return _cb($callback, $error);
+    }
 
     $self->{active_queries}++;
     $connection->$command(sub {
@@ -249,7 +251,7 @@ sub _command {
         $self->{throttler}->count($error);
 
         $self->{active_queries}--;
-        $self->_command_dequeue if $self->{command_queue}{has_any};
+        $self->_schedule_command_dequeue if $self->{command_queue}{has_any};
 
         return $self->_command_failed($command, $callback, $args, $command_info, $error) if $error;
         return _cb($callback, $error, $result);
@@ -260,9 +262,6 @@ sub _command {
 SLOWPATH:
     return $self->_command_slowpath($command, $callback, $args, $command_info);
 
-FAILFAST:
-    return _cb($callback, "Client-induced failure by throttling mechanism");
-
 OVERFLOW:
     return $self->_command_enqueue($command, $callback, $args, $command_info);
 }
@@ -281,8 +280,8 @@ sub _command_slowpath {
             $self->{pool}->get_one_cb($next);
         }, sub {
             my ($next, $connection)= @_;
-            if ($self->{throttler}->should_fail()) {
-                return $next->("Client-induced failure by throttling mechanism");
+            if (my $error= $self->{throttler}->should_fail()) {
+                return $next->($error);
             }
             $connection->$command($next, @$args);
         }
@@ -291,7 +290,7 @@ sub _command_slowpath {
         $self->{throttler}->count($error);
 
         $self->{active_queries}--;
-        $self->_command_dequeue if $self->{command_queue}{has_any};
+        $self->_schedule_command_dequeue if $self->{command_queue}{has_any};
 
         return $self->_command_failed($command, $callback, $args, $command_info, $error) if $error;
         return _cb($callback, $error, $result);
@@ -349,11 +348,18 @@ sub _command_enqueue {
     return;
 }
 
-sub _command_dequeue {
+sub _schedule_command_dequeue {
     my ($self)= @_;
-    my $item= $self->{command_queue}->dequeue or return;
-    $self->_command_slowpath(@$item);
-    return;
+    unless ($self->{command_callback_scheduled}++) {
+        $self->{async_io}->later(sub {
+            delete $self->{command_callback_scheduled};
+
+            while ($self->{command_queue}{has_any} && $self->{active_queries} < $self->{options}{max_concurrent_queries}) {
+                my $item= $self->{command_queue}->dequeue or return;
+                $self->_command_slowpath(@$item);
+            }
+        });
+    }
 }
 
 # Utility functions that wrap query functions
@@ -526,7 +532,7 @@ Cassandra::Client - Perl library for accessing Cassandra using its binary networ
 
 =head1 VERSION
 
-version 0.13_007
+version 0.13_008
 
 =head1 DESCRIPTION
 
