@@ -1,8 +1,8 @@
 package Cassandra::Client::AsyncAnyEvent;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::AsyncAnyEvent::VERSION = '0.13_007'; # TRIAL
+$Cassandra::Client::AsyncAnyEvent::VERSION = '0.13_008'; # TRIAL
 
-$Cassandra::Client::AsyncAnyEvent::VERSION = '0.13007';use 5.010;
+$Cassandra::Client::AsyncAnyEvent::VERSION = '0.13008';use 5.010;
 use strict;
 use warnings;
 
@@ -146,6 +146,11 @@ sub timer {
     });
 }
 
+sub later {
+    my ($self, $callback)= @_;
+    AE::postpone($callback);
+}
+
 # $something->($async->wait(my $w)); my ($error, $result)= $w->();
 sub wait {
     my ($self)= @_;
@@ -178,7 +183,7 @@ Cassandra::Client::AsyncAnyEvent
 
 =head1 VERSION
 
-version 0.13_007
+version 0.13_008
 
 =head1 AUTHOR
 
