@@ -1,8 +1,8 @@
 package Cassandra::Client::AsyncEV;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::AsyncEV::VERSION = '0.13_007'; # TRIAL
+$Cassandra::Client::AsyncEV::VERSION = '0.13_008'; # TRIAL
 
-$Cassandra::Client::AsyncEV::VERSION = '0.13007';use 5.010;
+$Cassandra::Client::AsyncEV::VERSION = '0.13008';use 5.010;
 use strict;
 use warnings;
 
@@ -131,6 +131,11 @@ sub timer {
     });
 }
 
+sub later {
+    my ($self, $callback)= @_;
+    $self->timer($callback, 0);
+}
+
 # $something->($async->wait(my $w)); my ($error, $result)= $w->();
 sub wait {
     my ($self)= @_;
@@ -170,7 +175,7 @@ Cassandra::Client::AsyncEV
 
 =head1 VERSION
 
-version 0.13_007
+version 0.13_008
 
 =head1 AUTHOR
 
