@@ -1,13 +1,14 @@
 package Cassandra::Client::Policy::Throttle::Adaptive;
 our $AUTHORITY = 'cpan:TVDW';
-$Cassandra::Client::Policy::Throttle::Adaptive::VERSION = '0.13_007'; # TRIAL
+$Cassandra::Client::Policy::Throttle::Adaptive::VERSION = '0.13_008'; # TRIAL
 
-$Cassandra::Client::Policy::Throttle::Adaptive::VERSION = '0.13007';use parent 'Cassandra::Client::Policy::Throttle::Default';
+$Cassandra::Client::Policy::Throttle::Adaptive::VERSION = '0.13008';use parent 'Cassandra::Client::Policy::Throttle::Default';
 use 5.010;
 use strict;
 use warnings;
 use Time::HiRes qw/CLOCK_MONOTONIC/;
 use Ref::Util qw/is_blessed_ref/;
+use Cassandra::Client::Error::ClientThrottlingError;
 
 sub new {
     my ($class, %args)= @_;
@@ -40,13 +41,13 @@ sub should_fail {
     return unless $fail;
 
     $self->count(undef, 1);
-    return 1;
+    return Cassandra::Client::Error::ClientThrottlingError->new;
 }
 
 sub count {
     my ($self, $error, $force_error)= @_;
     $self->{window_total}++;
-    my $success= !(is_blessed_ref($error) && $error->is_timeout) && !$force_error;
+    my $success= !(is_blessed_ref($error) && $error->is_timeout && !$error->isa('Cassandra::Client::Error::ClientThrottlingError')) && !$force_error;
     push @{$self->{window}}, [ Time::HiRes::clock_gettime(CLOCK_MONOTONIC)+$self->{time}, $success ];
     $self->{window_success}++ if $success;
     return;
@@ -64,7 +65,7 @@ Cassandra::Client::Policy::Throttle::Adaptive
 
 =head1 VERSION
 
-version 0.13_007
+version 0.13_008
 
 =head1 AUTHOR
 
